## Master Bias

The master bias frames are the product of the [`soxs_mbias`](../_api/soxspipe.recipes.soxs_mbias.html) recipe. The master-bias frame is to be subtracted from science/calibration frames to remove the contribution to pixel counts resulting from the bias-voltage.

